diff --git a/auth_admin_passkey/README.rst b/auth_admin_passkey/README.rst
index 15be819dc..e49ec6635 100644
--- a/auth_admin_passkey/README.rst
+++ b/auth_admin_passkey/README.rst
@@ -4,7 +4,7 @@ Admin password become a passkey for all active logins
Functionality :
---------------
* Administrator has now the possibility to login in with any login;
- * By default, OpenERP will send a mail to user and admin to indicate them;
+ * By default, Odoo will send a mail to user and admin to indicate them;
* If a user and the admin have the same password, admin will be informed;
Technical information :
diff --git a/auth_admin_passkey/__init__.py b/auth_admin_passkey/__init__.py
index 088e71f64..3757327cd 100644
--- a/auth_admin_passkey/__init__.py
+++ b/auth_admin_passkey/__init__.py
@@ -1,7 +1,7 @@
# -*- encoding: utf-8 -*-
##############################################################################
#
-# Admin Passkey module for OpenERP
+# Admin Passkey module for Odoo
# Copyright (C) 2013-2014 GRAP (http://www.grap.coop)
# @author Sylvain LE GAL (https://twitter.com/legalsylvain)
#
diff --git a/auth_admin_passkey/__openerp__.py b/auth_admin_passkey/__openerp__.py
index 69b7c8b1c..ac9194aad 100644
--- a/auth_admin_passkey/__openerp__.py
+++ b/auth_admin_passkey/__openerp__.py
@@ -1,7 +1,7 @@
# -*- encoding: utf-8 -*-
##############################################################################
#
-# Admin Passkey module for OpenERP
+# Admin Passkey module for Odoo
# Copyright (C) 2013-2014 GRAP (http://www.grap.coop)
# @author Sylvain LE GAL (https://twitter.com/legalsylvain)
#
diff --git a/auth_admin_passkey/data/ir_config_parameter.xml b/auth_admin_passkey/data/ir_config_parameter.xml
index 7c7f3625d..6b32557a3 100644
--- a/auth_admin_passkey/data/ir_config_parameter.xml
+++ b/auth_admin_passkey/data/ir_config_parameter.xml
@@ -1,6 +1,6 @@
-
+
diff --git a/auth_admin_passkey/i18n/auth_admin_passkey.pot b/auth_admin_passkey/i18n/auth_admin_passkey.pot
index 04b30e9a5..ce1449bcf 100644
--- a/auth_admin_passkey/i18n/auth_admin_passkey.pot
+++ b/auth_admin_passkey/i18n/auth_admin_passkey.pot
@@ -1,6 +1,6 @@
##############################################################################
#
-# Admin Passkey module for OpenERP
+# Admin Passkey module for Odoo
# Copyright (C) 2013-2014 GRAP (http://www.grap.coop)
# @author Sylvain LE GAL (https://twitter.com/legalsylvain)
#
@@ -18,13 +18,13 @@
# along with this program. If not, see .
#
##############################################################################
-# Translation of OpenERP Server.
+# Translation of Odoo Server.
# This file contains the translation of the following modules:
# * auth_admin_passkey
#
msgid ""
msgstr ""
-"Project-Id-Version: OpenERP Server 7.0\n"
+"Project-Id-Version: Odoo Server 7.0\n"
"Report-Msgid-Bugs-To: \n"
"POT-Creation-Date: 2014-03-23 20:41+0000\n"
"PO-Revision-Date: 2014-03-23 20:41+0000\n"
@@ -85,17 +85,17 @@ msgstr ""
#. module: auth_admin_passkey
#: help:base.config.settings,auth_admin_passkey_send_to_user:0
-msgid "When the administrator use his password to login in with a different account, OpenERP will send an email to the account user."
+msgid "When the administrator use his password to login in with a different account, Odoo will send an email to the account user."
msgstr ""
#. module: auth_admin_passkey
#: help:base.config.settings,auth_admin_passkey_send_to_admin:0
-msgid "When the administrator use his password to login in with a different account, OpenERP will send an email to the admin user."
+msgid "When the administrator use his password to login in with a different account, Odoo will send an email to the admin user."
msgstr ""
#. module: auth_admin_passkey
#: code:addons/auth_admin_passkey/model/res_users.py:64
#, python-format
-msgid "[WARNING] OpenERP Security Risk"
+msgid "[WARNING] Odoo Security Risk"
msgstr ""
diff --git a/auth_admin_passkey/i18n/de.po b/auth_admin_passkey/i18n/de.po
index 9c0fbe653..64207cc96 100644
--- a/auth_admin_passkey/i18n/de.po
+++ b/auth_admin_passkey/i18n/de.po
@@ -67,18 +67,18 @@ msgstr "Benutzer"
#: help:base.config.settings,auth_admin_passkey_send_to_user:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the account user."
+"account, Odoo will send an email to the account user."
msgstr ""
#. module: auth_admin_passkey
#: help:base.config.settings,auth_admin_passkey_send_to_admin:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the admin user."
+"account, Odoo will send an email to the admin user."
msgstr ""
#. module: auth_admin_passkey
#: code:addons/auth_admin_passkey/model/res_users.py:86
#, python-format
-msgid "[WARNING] OpenERP Security Risk"
+msgid "[WARNING] Odoo Security Risk"
msgstr ""
diff --git a/auth_admin_passkey/i18n/es.po b/auth_admin_passkey/i18n/es.po
index 9cabcda2d..1f0761c76 100644
--- a/auth_admin_passkey/i18n/es.po
+++ b/auth_admin_passkey/i18n/es.po
@@ -67,18 +67,18 @@ msgstr "Usuarios"
#: help:base.config.settings,auth_admin_passkey_send_to_user:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the account user."
+"account, Odoo will send an email to the account user."
msgstr ""
#. module: auth_admin_passkey
#: help:base.config.settings,auth_admin_passkey_send_to_admin:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the admin user."
+"account, Odoo will send an email to the admin user."
msgstr ""
#. module: auth_admin_passkey
#: code:addons/auth_admin_passkey/model/res_users.py:86
#, python-format
-msgid "[WARNING] OpenERP Security Risk"
+msgid "[WARNING] Odoo Security Risk"
msgstr ""
diff --git a/auth_admin_passkey/i18n/fr.po b/auth_admin_passkey/i18n/fr.po
index 9cb88a83b..bba266faf 100644
--- a/auth_admin_passkey/i18n/fr.po
+++ b/auth_admin_passkey/i18n/fr.po
@@ -67,18 +67,18 @@ msgstr "Utilisateurs"
#: help:base.config.settings,auth_admin_passkey_send_to_user:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the account user."
-msgstr "Quand l'administrateur utilise son mot de passe pour s'authentifier avec un compte différent, OpenERP lui enverra un mail."
+"account, Odoo will send an email to the account user."
+msgstr "Quand l'administrateur utilise son mot de passe pour s'authentifier avec un compte différent, Odoo lui enverra un mail."
#. module: auth_admin_passkey
#: help:base.config.settings,auth_admin_passkey_send_to_admin:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the admin user."
-msgstr "Quand l'administrateur utilise son mot de passe pour s'authentifier avec un compte différent, OpenERP enverra un mail à l'utilisateur."
+"account, Odoo will send an email to the admin user."
+msgstr "Quand l'administrateur utilise son mot de passe pour s'authentifier avec un compte différent, Odoo enverra un mail à l'utilisateur."
#. module: auth_admin_passkey
#: code:addons/auth_admin_passkey/model/res_users.py:86
#, python-format
-msgid "[WARNING] OpenERP Security Risk"
-msgstr "[WARNING] Faille de sécurité sur OpenERP"
+msgid "[WARNING] Odoo Security Risk"
+msgstr "[WARNING] Faille de sécurité sur Odoo"
diff --git a/auth_admin_passkey/i18n/pt_BR.po b/auth_admin_passkey/i18n/pt_BR.po
index 361554e01..fd606c115 100644
--- a/auth_admin_passkey/i18n/pt_BR.po
+++ b/auth_admin_passkey/i18n/pt_BR.po
@@ -68,18 +68,18 @@ msgstr "Usuários"
#: help:base.config.settings,auth_admin_passkey_send_to_user:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the account user."
+"account, Odoo will send an email to the account user."
msgstr "Quando o administrador usa sua senha para dar login com uma conta diferente, OPENERP irá enviar um email para a conta do usuário."
#. module: auth_admin_passkey
#: help:base.config.settings,auth_admin_passkey_send_to_admin:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the admin user."
+"account, Odoo will send an email to the admin user."
msgstr "Quando o administrador usa sua senha para dar login com uma conta diferente, OPENERP irá enviar um email para a conta do administrador."
#. module: auth_admin_passkey
#: code:addons/auth_admin_passkey/model/res_users.py:86
#, python-format
-msgid "[WARNING] OpenERP Security Risk"
-msgstr "[AVISO] OpenERP Risco de Segurança"
+msgid "[WARNING] Odoo Security Risk"
+msgstr "[AVISO] Odoo Risco de Segurança"
diff --git a/auth_admin_passkey/i18n/sl.po b/auth_admin_passkey/i18n/sl.po
index 88c41d5f4..d1e6a9796 100644
--- a/auth_admin_passkey/i18n/sl.po
+++ b/auth_admin_passkey/i18n/sl.po
@@ -68,18 +68,18 @@ msgstr "Uporabniki"
#: help:base.config.settings,auth_admin_passkey_send_to_user:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the account user."
-msgstr "Ko administrator uporabi svoje geslo za prijavo v drug račun, bo OpenERP poslal e-pošto uporabniku računa."
+"account, Odoo will send an email to the account user."
+msgstr "Ko administrator uporabi svoje geslo za prijavo v drug račun, bo Odoo poslal e-pošto uporabniku računa."
#. module: auth_admin_passkey
#: help:base.config.settings,auth_admin_passkey_send_to_admin:0
msgid ""
"When the administrator use his password to login in with a different "
-"account, OpenERP will send an email to the admin user."
-msgstr "Ko administrator uporabi svoje geslo za prijavo v drug račun, bo OpenERP poslal e-pošto administratorju."
+"account, Odoo will send an email to the admin user."
+msgstr "Ko administrator uporabi svoje geslo za prijavo v drug račun, bo Odoo poslal e-pošto administratorju."
#. module: auth_admin_passkey
#: code:addons/auth_admin_passkey/model/res_users.py:86
#, python-format
-msgid "[WARNING] OpenERP Security Risk"
-msgstr "[OPOZORILO] OpenERP varnostno tveganje"
+msgid "[WARNING] Odoo Security Risk"
+msgstr "[OPOZORILO] Odoo varnostno tveganje"
diff --git a/auth_admin_passkey/model/__init__.py b/auth_admin_passkey/model/__init__.py
index 60c3790aa..364290a16 100644
--- a/auth_admin_passkey/model/__init__.py
+++ b/auth_admin_passkey/model/__init__.py
@@ -1,7 +1,7 @@
# -*- encoding: utf-8 -*-
##############################################################################
#
-# Admin Passkey module for OpenERP
+# Admin Passkey module for Odoo
# Copyright (C) 2013-2014 GRAP (http://www.grap.coop)
# @author Sylvain LE GAL (https://twitter.com/legalsylvain)
#
diff --git a/auth_admin_passkey/model/res_config.py b/auth_admin_passkey/model/res_config.py
index 11c7fa083..6be3b67e4 100644
--- a/auth_admin_passkey/model/res_config.py
+++ b/auth_admin_passkey/model/res_config.py
@@ -1,7 +1,7 @@
# -*- encoding: utf-8 -*-
##############################################################################
#
-# Admin Passkey module for OpenERP
+# Admin Passkey module for Odoo
# Copyright (C) 2013-2014 GRAP (http://www.grap.coop)
# @author Sylvain LE GAL (https://twitter.com/legalsylvain)
#
@@ -64,13 +64,13 @@ class base_config_settings(TransientModel):
'auth_admin_passkey_send_to_admin': fields.boolean(
'Send email to admin user.',
help="""When the administrator use his password to login in """
- """with a different account, OpenERP will send an email """
+ """with a different account, Odoo will send an email """
"""to the admin user.""",
),
'auth_admin_passkey_send_to_user': fields.boolean(
string='Send email to user.',
help="""When the administrator use his password to login in """
- """with a different account, OpenERP will send an email """
+ """with a different account, Odoo will send an email """
"""to the account user.""",
),
}
diff --git a/auth_admin_passkey/tests/__init__.py b/auth_admin_passkey/tests/__init__.py
index 8150785b1..48547d84d 100644
--- a/auth_admin_passkey/tests/__init__.py
+++ b/auth_admin_passkey/tests/__init__.py
@@ -1,7 +1,7 @@
# -*- encoding: utf-8 -*-
##############################################################################
#
-# Admin Passkey module for OpenERP
+# Admin Passkey module for Odoo
# Copyright (C) 2013-2014 GRAP (http://www.grap.coop)
# @author Sylvain LE GAL (https://twitter.com/legalsylvain)
#
diff --git a/auth_admin_passkey/tests/test_auth_admin_passkey.py b/auth_admin_passkey/tests/test_auth_admin_passkey.py
index 2ce02d26c..a8919f439 100644
--- a/auth_admin_passkey/tests/test_auth_admin_passkey.py
+++ b/auth_admin_passkey/tests/test_auth_admin_passkey.py
@@ -1,7 +1,7 @@
# -*- encoding: utf-8 -*-
##############################################################################
#
-# Admin Passkey module for OpenERP
+# Admin Passkey module for Odoo
# Copyright (C) 2013-2014 GRAP (http://www.grap.coop)
# @author Sylvain LE GAL (https://twitter.com/legalsylvain)
#
diff --git a/auth_admin_passkey/view/res_config_view.xml b/auth_admin_passkey/view/res_config_view.xml
index 990729705..2fec2a6ff 100644
--- a/auth_admin_passkey/view/res_config_view.xml
+++ b/auth_admin_passkey/view/res_config_view.xml
@@ -1,6 +1,6 @@
-
+
diff --git a/auth_admin_passkey/model/res_users.py b/auth_admin_passkey/model/res_users.py
index d0a5a8aa2..d4ad3716e 100644
--- a/auth_admin_passkey/model/res_users.py
+++ b/auth_admin_passkey/model/res_users.py
@@ -1,7 +1,7 @@
# -*- encoding: utf-8 -*-
##############################################################################
#
# Admin Passkey module for OpenERP
# Copyright (C) 2013-2014 GRAP (http://www.grap.coop)
# @author Sylvain LE GAL (https://twitter.com/legalsylvain)
#
@@ -83,7 +83,7 @@ class res_users(Model):
mail_obj.create(cr, SUPERUSER_ID, {
'email_to': admin_user.email,
'subject': self._get_translation(
- cr, admin_user.lang, _('[WARNING] OpenERP Security Risk')),
+ cr, admin_user.lang, _('[WARNING] Odoo Security Risk')),
'body_html': self._get_translation(
cr, admin_user.lang, _(
"""
@@ -1,7 +1,7 @@
##############################################################################
#
-# Admin Passkey module for OpenERP
+# Admin Passkey module for Odoo
# Copyright (C) 2013-2014 GRAP (http://www.grap.coop)
# @author Sylvain LE GAL (https://twitter.com/legalsylvain)
User with login '%s' has the same """